Changelog
=========

`v1.1.1 <https://github.com/abhiabhi94/django-flag-app/tree/1.1.1>`__
------------------------------------------------------------------------

`Full
Changelog <https://github.com/abhiabhi94/django-flag-app/compare/v1.1.1...v1.1.0>`__

**Merged pull requests:**

-  fix: 🐛 default_app_config warnings for django>=3.2
   `#33 <https://github.com/abhiabhi94/django-flag-app/pull/33>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  fix: 🐛 environment syntax for workflow
   `#32 <https://github.com/abhiabhi94/django-flag-app/pull/32>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  fix: 🐛 syntax for release workflow
   `#31 <https://github.com/abhiabhi94/django-flag-app/pull/31>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)

`v1.1.0 <https://github.com/abhiabhi94/django-flag-app/tree/v1.1.0>`__ (2021-04-18)
-----------------------------------------------------------------------------------

`Full
Changelog <https://github.com/abhiabhi94/django-flag-app/compare/v1.0.1...v1.1.0>`__

**Merged pull requests:**

-  chore: 🚀 Release 1.1.0
   `#30 <https://github.com/abhiabhi94/django-flag-app/pull/30>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  feat: ✨ Add support for python3.9 and django3.2
   `#29 <https://github.com/abhiabhi94/django-flag-app/pull/29>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  docs: 📚️ 🐛 build
   `#28 <https://github.com/abhiabhi94/django-flag-app/pull/28>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)

`v1.0.1 <https://github.com/abhiabhi94/django-flag-app/tree/v1.0.1>`__ (2021-03-11)
-----------------------------------------------------------------------------------

`Full
Changelog <https://github.com/abhiabhi94/django-flag-app/compare/v1.0.0...v1.0.1>`__

**Fixed bugs:**

-  Use of \`get_user_model’ at module level in manager causes circular
   import
   `#19 <https://github.com/abhiabhi94/django-flag-app/issues/19>`__

**Merged pull requests:**

-  fix: 🐛 version issues, bump version number
   `#27 <https://github.com/abhiabhi94/django-flag-app/pull/27>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  fix: 🐛 contributing link to allow PyPi release
   `#26 <https://github.com/abhiabhi94/django-flag-app/pull/26>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  chore: 🔧 🚀 Update release notes
   `#25 <https://github.com/abhiabhi94/django-flag-app/pull/25>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  fix: 🐛 version number according to PEP440
   `#24 <https://github.com/abhiabhi94/django-flag-app/pull/24>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  🚨 Switch to pytest
   `#23 <https://github.com/abhiabhi94/django-flag-app/pull/23>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  :memo: Cleanup to have just one source of truth
   `#22 <https://github.com/abhiabhi94/django-flag-app/pull/22>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  :truck: chore: Rename master branch to main
   `#20 <https://github.com/abhiabhi94/django-flag-app/pull/20>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Avoid circular import issues.
   `#18 <https://github.com/abhiabhi94/django-flag-app/pull/18>`__
   (`TSolo315 <https://github.com/TSolo315>`__)
-  Add test for the case when drf is not installed
   `#16 <https://github.com/abhiabhi94/django-flag-app/pull/16>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)

`v1.0.0 <https://github.com/abhiabhi94/django-flag-app/tree/v1.0.0>`__ (2020-11-17)
-----------------------------------------------------------------------------------

`Full
Changelog <https://github.com/abhiabhi94/django-flag-app/compare/v0.1.1...v1.0.0>`__

**Merged pull requests:**

-  Update docs for release of v1.0.0
   `#15 <https://github.com/abhiabhi94/django-flag-app/pull/15>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix API response
   `#14 <https://github.com/abhiabhi94/django-flag-app/pull/14>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Add app settings
   `#13 <https://github.com/abhiabhi94/django-flag-app/pull/13>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Add pypi badge, fix changelog documentation
   `#12 <https://github.com/abhiabhi94/django-flag-app/pull/12>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)

`v0.1.1 <https://github.com/abhiabhi94/django-flag-app/tree/v0.1.1>`__ (2020-10-22)
-----------------------------------------------------------------------------------

`Full
Changelog <https://github.com/abhiabhi94/django-flag-app/compare/v0.1.0...v0.1.1>`__

**Merged pull requests:**

-  Release v0.1.1
   `#11 <https://github.com/abhiabhi94/django-flag-app/pull/11>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix icon title when flagging/unflagging
   `#10 <https://github.com/abhiabhi94/django-flag-app/pull/10>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix template for unauthenticated users
   `#9 <https://github.com/abhiabhi94/django-flag-app/pull/9>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix Readme links
   `#8 <https://github.com/abhiabhi94/django-flag-app/pull/8>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix travis CI to deploy only once
   `#7 <https://github.com/abhiabhi94/django-flag-app/pull/7>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)

`v0.1.0 <https://github.com/abhiabhi94/django-flag-app/tree/v0.1.0>`__ (2020-09-28)
-----------------------------------------------------------------------------------

`Full
Changelog <https://github.com/abhiabhi94/django-flag-app/compare/47b8b136bd62b2c5a75d04ac76ca25f01e91b03e...v0.1.0>`__

**Merged pull requests:**

-  Add sphninx read the docs theme, release first version
   `#6 <https://github.com/abhiabhi94/django-flag-app/pull/6>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix build for docs
   `#5 <https://github.com/abhiabhi94/django-flag-app/pull/5>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Fix language on GitHub
   `#4 <https://github.com/abhiabhi94/django-flag-app/pull/4>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Release and deploy to PyPI, add manifest file
   `#3 <https://github.com/abhiabhi94/django-flag-app/pull/3>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Add documentation
   `#2 <https://github.com/abhiabhi94/django-flag-app/pull/2>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)
-  Change format for documentation files to RST
   `#1 <https://github.com/abhiabhi94/django-flag-app/pull/1>`__
   (`abhiabhi94 <https://github.com/abhiabhi94>`__)

\* *This Changelog was automatically generated
by*\ `github_changelog_generator <https://github.com/github-changelog-generator/github-changelog-generator>`__
